@@ -12,7 +12,7 @@ Provides logging to syslog()
     use Sys::Syslog;
 
     # Get a new logger
-    my $log = Log::Fine->getLogger("foo");
+    my $log = Log::Fine->logger("foo");
 
     # register a syslog handle
     my $handle = Log::Fine::Handle::Syslog
@@ -45,7 +45,7 @@ use base qw( Log::Fine::Handle );
 
 use File::Basename;
 use Log::Fine;
-use Sys::Syslog qw( :standard :macros );
+use Sys::Syslog 0.13 qw( :standard :macros );
 
 # Constant: LOG_MAPPING
 #
@@ -66,9 +66,9 @@ use constant LOG_MAPPING => {
 
 =head1 METHODS
 
-=head2 msgWrite($lvl, $msg, $skip)
+=head2 msgWrite
 
-See L<Log::Fine::Handle>
+See L<Log::Fine::Handle/msgWrite>
 
 Note that this method B<does not> make use of a formatter as this is
 handled by the syslog facility.
@@ -110,12 +110,12 @@ sub _init
 
         # set the default logopts (to be passed to Sys::Syslog::openlog()
         $self->{logopts} = "pid"
-                unless (defined $self->{logopts} and $self->{logopts} =~ /\w+/);
+            unless (defined $self->{logopts} and $self->{logopts} =~ /\w+/);
 
         # set the default facility
         $self->{facility} = LOG_LOCAL0
-                unless (defined $self->{faciity}
-                        and $self->{facility} =~ /\w+/);
+            unless (defined $self->{facility}
+                    and $self->{facility} =~ /\w+/);
 
         # open the syslog connection
         openlog($self->{ident}, $self->{logopts}, $self->{facility});
@@ -176,11 +176,11 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: Syslog.pm 18 2008-05-09 18:24:46Z cfuhrman $
+  $Id: 9018464527a1c0a7215886f362a0c96166bf3dea $
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008 Christopher M. Fuhrman, 
+Copyright (c) 2008, 2010 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
